@@ -12,6 +12,7 @@
 #include "libkcddb/config.h"
 
 class CDDBConfigWidget;
+class KPluginMetaData;
 
 
 class CDDBModule : public KCModule
@@ -20,7 +21,11 @@ class CDDBModule : public KCModule
 
   public:
 
-	CDDBModule(QWidget * parent, const QVariantList & args);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    CDDBModule(QWidget * parent, const QVariantList & args);
+#else
+    CDDBModule(QObject * parent, const KPluginMetaData &metaData);
+#endif
 
   public Q_SLOTS:
 
@@ -29,9 +34,7 @@ class CDDBModule : public KCModule
     void load() override;
 
   protected:
-
-    void            checkSettings() const;
-    void            updateWidgetsFromConfig(const KCDDB::Config &);
+    void checkSettings() const;
 
   private:
 
